==> kitchenprojectiles-1.0.0%2Bmc1.21.8-sources.jar: archives/tater/kitchenprojectiles/mixin/client/ItemRendererMixin.java <==
package archives.tater.kitchenprojectiles.mixin.client;

import archives.tater.kitchenprojectiles.KnifeEntityRenderer;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4722;
import net.minecraft.class_918;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.ModifyArg;

@Mixin(class_918.class)
public class ItemRendererMixin {
    @ModifyArg(
            method = "renderItem(Lnet/minecraft/item/ItemDisplayContext;Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;II[ILjava/util/List;Lnet/minecraft/client/render/RenderLayer;Lnet/minecraft/client/render/item/ItemRenderState$Glint;)V",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/render/item/ItemRenderer;renderBakedItemQuads(Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumer;Ljava/util/List;[III)V"),
            index = 1
    )
    private static class_4588 intangibleTranslucent(class_4588 vertices, @Local(argsOnly = true) class_4597 vertexConsumers) {
        if (!KnifeEntityRenderer.intangible)
            return vertices;
        return vertexConsumers.getBuffer(class_4722.method_29382());
    }

    @ModifyArg(
            method = "renderBakedItemQuads",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/render/VertexConsumer;quad(Lnet/minecraft/client/util/math/MatrixStack$Entry;Lnet/minecraft/client/render/model/BakedQuad;FFFFII)V"),
            index = 5
    )
    private static float intangibleTranslucent(float alpha) {
        if (!KnifeEntityRenderer.intangible)
            return alpha;
        return 0.5f;
    }
}

==> kitchenprojectiles-1.0.1%2Bmc1.21.10-sources.jar: archives/tater/kitchenprojectiles/mixin/client/ItemRendererMixin.java <==
package archives.tater.kitchenprojectiles.mixin.client;

import archives.tater.kitchenprojectiles.KnifeEntityRenderer;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4722;
import net.minecraft.class_918;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.ModifyArg;

@Mixin(class_918.class)
public class ItemRendererMixin {
    @ModifyArg(
            method = "renderItem(Lnet/minecraft/item/ItemDisplayContext;Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumerProvider;II[ILjava/util/List;Lnet/minecraft/client/render/RenderLayer;Lnet/minecraft/client/render/item/ItemRenderState$Glint;)V",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/render/item/ItemRenderer;renderBakedItemQuads(Lnet/minecraft/client/util/math/MatrixStack;Lnet/minecraft/client/render/VertexConsumer;Ljava/util/List;[III)V"),
            index = 1
    )
    private static class_4588 intangibleTranslucent(class_4588 vertices, @Local(argsOnly = true) class_4597 vertexConsumers) {
        if (!KnifeEntityRenderer.intangible)
            return vertices;
        return vertexConsumers.method_73477(class_4722.method_29382());
    }

    @ModifyArg(
            method = "renderBakedItemQuads",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/render/VertexConsumer;quad(Lnet/minecraft/client/util/math/MatrixStack$Entry;Lnet/minecraft/client/render/model/BakedQuad;FFFFII)V"),
            index = 5
    )
    private static float intangibleTranslucent(float alpha) {
        if (!KnifeEntityRenderer.intangible)
            return alpha;
        return 0.5f;
    }
}
